/* ========================================
 *
 * Copyright YOUR COMPANY, THE YEAR
 * All Rights Reserved
 * UNPUBLISHED, LICENSED SOFTWARE.
 *
 * CONFIDENTIAL AND PROPRIETARY INFORMATION
 * WHICH IS THE PROPERTY OF your company.
 *
 * ========================================
*/

#include "stepper_1.h"
#include "device.h"

void stepper_1_start()
{
    stepper_1_Counter_Start();
}

//Determines what direction and the distance to a desired location.
int stepper_1_desiredToRelative(int desired)
{
    int relative = 0;
    
    //Determine what direction we need to go.
    int distance = stepper_1_currentPos + stepper_1_POS_PER_REV - desired;
    if(distance < (stepper_1_POS_PER_REV/2))
        relative = -1;
    else
        relative = 1;
    
    relative *= distance;
    
    return relative;
}

//Takes a step of the default size toward a desired position.
void stepper_1_stepTowardDesired(int desired)
{
    int relative = stepper_1_desiredToRelative(desired);
    
    if(relative > 0)    //Should probably have protection for very small offsets, smaller than possible step.
    {
        stepper_1_setDirection(1);
        //Can add code here to take bigger steps if farther from desired location.
        stepper_1_step();
    }
    else if (relative < 0)
    {
        stepper_1_setDirection(0);
        //Can add code here to take bigger steps if farther from desired location.
        stepper_1_step();
    }
    
}

//Take a single step of the default size
void stepper_1_step()
{
    if(stepper_1_counterStatus_Read())
    {
        uint8 val = stepper_1_outputs_Read();    //Get current register value
        val = (val | 0b01000);                          //Set bit 3 high.
        stepper_1_outputs_Write(val);            //Write the new value to the register
        CyDelayUs(1);                                   //Wait long enough for the sensor driver.
        val = val & 0b10111;                            //Set the bit low again
        stepper_1_outputs_Write(val);            //Write
        
        stepper_1_resetCounter_Write(1);         //Reset the step wait counter.
        
        if(stepper_1_outputs_Read() & 0b10000)
            stepper_1_currentPos += 1;   //This isn't actually correct, since the pos is in 1/100 of a degree.
        else
            stepper_1_currentPos -= 1;
    }
}

//Set the default step size. Can be changed at any time.
//See A4988 stepper driver datasheet for more details
void stepper_1_setStepSize(uint8 stepMode)
{
    if(stepMode == 1)
    {
         uint8 val= stepper_1_outputs_Read();
         val = val & 0b11000;                         //Set MS1, MS2, MS3 low.
        stepper_1_outputs_Write(val);
        
        stepper_1_stepSize = stepMode;
        stepper_1_updateConversion();
    }
    else if(stepMode == 2)
    {
         uint8 val= stepper_1_outputs_Read();
         val = val & 0b11000;                         //Set MS1, MS2, MS3 low.
         val = val | 0b00001;                         //Set MS1 high.
        stepper_1_outputs_Write(val);
        
        stepper_1_stepSize = stepMode;
        stepper_1_updateConversion();
    }
    else if(stepMode == 4)
    {
         uint8 val= stepper_1_outputs_Read();
         val = val & 0b11000;                         //Set MS1, MS2, MS3 low.
         val = val | 0b00010;                         //Set MS2 high.
        stepper_1_outputs_Write(val);
        
        stepper_1_stepSize = stepMode;
        stepper_1_updateConversion();
    }
    else if(stepMode == 8)
    {
         uint8 val= stepper_1_outputs_Read();
         val = val & 0b11000;                         //Set MS1, MS2, MS3 low.
         val = val | 0b00011;                         //Set MS1 and MS2 high.
        stepper_1_outputs_Write(val);
        
        stepper_1_stepSize = stepMode;
        stepper_1_updateConversion();
    }
    else if(stepMode == 16)
    {
         uint8 val= stepper_1_outputs_Read();
         val = val | 0b00111;                         //Set MS1, MS2, MS3 high.
        stepper_1_outputs_Write(val);
        
        stepper_1_stepSize = stepMode;
        stepper_1_updateConversion();
    }

}

//Set the current rotation direction. 1 is CW, 0 is CCW
void stepper_1_setDirection(uint8 direction)
{
    if(direction)
    {
        uint8 val= stepper_1_outputs_Read();
         val = val | 0b10000;                         //Set DIR high.
        stepper_1_outputs_Write(val);
    }
    else
    {
         uint8 val= stepper_1_outputs_Read();
         val = val & 0b01111;                         //Set DIR low.
        stepper_1_outputs_Write(val);
    }
    
}

//Set the min time between steps
void stepper_1_setStepTime(uint16 time)
{
    stepper_1_stepTime = time;
    stepper_1_Counter_WritePeriod(stepper_1_stepTime);
}

//Set the current position.
void stepper_1_setPos(int pos)
{
    stepper_1_currentPos = pos;
}

//Set how many steps per rev. the motor has.
void stepper_1_setStepsPerRev(int steps)
{
    stepper_1_stepsPerRev = steps;
    stepper_1_updateConversion();
}

//Update the conversion factor
void stepper_1_updateConversion()
{
    stepper_1_conversion = (360*100)/(stepper_1_stepsPerRev*stepper_1_stepSize);
}


/* [] END OF FILE */
