/*******************************************************************************
* File Name: stepper_1_Counter_1_PM.c  
* Version 2.40
*
*  Description:
*    This file provides the power management source code to API for the
*    Counter.  
*
*   Note:
*     None
*
*******************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
********************************************************************************/

#include "stepper_1_Counter_1.h"

static stepper_1_Counter_1_backupStruct stepper_1_Counter_1_backup;


/*******************************************************************************
* Function Name: stepper_1_Counter_1_SaveConfig
********************************************************************************
* Summary:
*     Save the current user configuration
*
* Parameters:  
*  void
*
* Return: 
*  void
*
* Global variables:
*  stepper_1_Counter_1_backup:  Variables of this global structure are modified to 
*  store the values of non retention configuration registers when Sleep() API is 
*  called.
*
*******************************************************************************/
void stepper_1_Counter_1_SaveConfig(void) 
{
    #if (!stepper_1_Counter_1_UsingFixedFunction)

        stepper_1_Counter_1_backup.CounterUdb = stepper_1_Counter_1_ReadCounter();

        #if (CY_UDB_V0)
            stepper_1_Counter_1_backup.CounterPeriod = stepper_1_Counter_1_ReadPeriod();
            stepper_1_Counter_1_backup.CompareValue = stepper_1_Counter_1_ReadCompare();
            stepper_1_Counter_1_backup.InterruptMaskValue = stepper_1_Counter_1_STATUS_MASK;
        #endif /* CY_UDB_V0 */

        #if(!stepper_1_Counter_1_ControlRegRemoved)
            stepper_1_Counter_1_backup.CounterControlRegister = stepper_1_Counter_1_ReadControlRegister();
        #endif /* (!stepper_1_Counter_1_ControlRegRemoved) */

    #endif /* (!stepper_1_Counter_1_UsingFixedFunction) */
}


/*******************************************************************************
* Function Name: stepper_1_Counter_1_RestoreConfig
********************************************************************************
*
* Summary:
*  Restores the current user configuration.
*
* Parameters:  
*  void
*
* Return: 
*  void
*
* Global variables:
*  stepper_1_Counter_1_backup:  Variables of this global structure are used to 
*  restore the values of non retention registers on wakeup from sleep mode.
*
*******************************************************************************/
void stepper_1_Counter_1_RestoreConfig(void) 
{      
    #if (!stepper_1_Counter_1_UsingFixedFunction)

        #if (CY_UDB_V0)
            uint8 stepper_1_Counter_1_interruptState;
        #endif  /* (CY_UDB_V0) */

       stepper_1_Counter_1_WriteCounter(stepper_1_Counter_1_backup.CounterUdb);

        #if (CY_UDB_V0)
            stepper_1_Counter_1_WritePeriod(stepper_1_Counter_1_backup.CounterPeriod);
            stepper_1_Counter_1_WriteCompare(stepper_1_Counter_1_backup.CompareValue);

            stepper_1_Counter_1_interruptState = CyEnterCriticalSection();
            stepper_1_Counter_1_STATUS_AUX_CTRL |= stepper_1_Counter_1_STATUS_ACTL_INT_EN_MASK;
            CyExitCriticalSection(stepper_1_Counter_1_interruptState);

            stepper_1_Counter_1_STATUS_MASK = stepper_1_Counter_1_backup.InterruptMaskValue;
        #endif  /* (CY_UDB_V0) */

        #if(!stepper_1_Counter_1_ControlRegRemoved)
            stepper_1_Counter_1_WriteControlRegister(stepper_1_Counter_1_backup.CounterControlRegister);
        #endif /* (!stepper_1_Counter_1_ControlRegRemoved) */

    #endif /* (!stepper_1_Counter_1_UsingFixedFunction) */
}


/*******************************************************************************
* Function Name: stepper_1_Counter_1_Sleep
********************************************************************************
* Summary:
*     Stop and Save the user configuration
*
* Parameters:  
*  void
*
* Return: 
*  void
*
* Global variables:
*  stepper_1_Counter_1_backup.enableState:  Is modified depending on the enable 
*  state of the block before entering sleep mode.
*
*******************************************************************************/
void stepper_1_Counter_1_Sleep(void) 
{
    #if(!stepper_1_Counter_1_ControlRegRemoved)
        /* Save Counter's enable state */
        if(stepper_1_Counter_1_CTRL_ENABLE == (stepper_1_Counter_1_CONTROL & stepper_1_Counter_1_CTRL_ENABLE))
        {
            /* Counter is enabled */
            stepper_1_Counter_1_backup.CounterEnableState = 1u;
        }
        else
        {
            /* Counter is disabled */
            stepper_1_Counter_1_backup.CounterEnableState = 0u;
        }
    #else
        stepper_1_Counter_1_backup.CounterEnableState = 1u;
        if(stepper_1_Counter_1_backup.CounterEnableState != 0u)
        {
            stepper_1_Counter_1_backup.CounterEnableState = 0u;
        }
    #endif /* (!stepper_1_Counter_1_ControlRegRemoved) */
    
    stepper_1_Counter_1_Stop();
    stepper_1_Counter_1_SaveConfig();
}


/*******************************************************************************
* Function Name: stepper_1_Counter_1_Wakeup
********************************************************************************
*
* Summary:
*  Restores and enables the user configuration
*  
* Parameters:  
*  void
*
* Return: 
*  void
*
* Global variables:
*  stepper_1_Counter_1_backup.enableState:  Is used to restore the enable state of 
*  block on wakeup from sleep mode.
*
*******************************************************************************/
void stepper_1_Counter_1_Wakeup(void) 
{
    stepper_1_Counter_1_RestoreConfig();
    #if(!stepper_1_Counter_1_ControlRegRemoved)
        if(stepper_1_Counter_1_backup.CounterEnableState == 1u)
        {
            /* Enable Counter's operation */
            stepper_1_Counter_1_Enable();
        } /* Do nothing if Counter was disabled before */    
    #endif /* (!stepper_1_Counter_1_ControlRegRemoved) */
    
}


/* [] END OF FILE */
